@@ -49,3 +49,22 @@ class Site:
                                                              'AppEditor', 'ComplianceAssetId', 'Modified', 'Created',
                                                              'Author', 'Editor', 'Attachments')
         return [i for i in self.get_list(name).fields.get().execute_query() if selector(i)]
+
+    @property
+    def users(self):
+        if self._users is None:
+            self._users = {}
+            for i in self._context.web.site_users.get().execute_query():
+                if i.principal_type == 1 and i.user_principal_name is not None:
+                    name = i.title.split('(')[0].strip()
+                    if ', ' in name:
+                        family_name, given_name = name.split(', ')
+                    else:
+                        given_name, family_name = name.split('.')
+                    given_name = given_name.capitalize()
+                    family_name = family_name.capitalize()
+                    name = f"{family_name}, {given_name}"
+                    email = i.get_property('Email').lower()
+                    self._users[i.id] = {'name': name, 'family_name': family_name, 'given_name': given_name,
+                                         'email': email}
+        return self._users
